MethodChannelCallKeep class final

Method channel implementation for CallKeepPlatform

Inheritance

Constructors

MethodChannelCallKeep()

Properties

config ↔ CallKeepConfig?
getter/setter pairinherited
eventChannel ↔ EventChannel
getter/setter pair
handler ← CallEventHandler
Set the handler to handle CallKeep events.
no getteroverride
hashCode → int
The hash code for this object.
no setterinherited
isCallDisplayedNatively → bool
Check if the incoming call is displayed natively.
no setteroverride
methodChannel ↔ MethodChannel
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptCall(String uuid) → Future<void>
Accept an incoming call with the specified uuid.
override
activeCalls() → Future<List<CallEvent>>
Get active calls.
override
configure(CallKeepConfig config) → void
Configures the plugin.
override
displayIncomingCall(CallEvent data) → Future<void>
Show Incoming call UI.
override
dispose() → void
Disposes of the resources used by the plugin.
override
endAllCalls() → Future<void>
End all calls.
override
endCall(String uuid) → Future<void>
End an Incoming/Outgoing call with the specified uuid.
override
getDevicePushTokenVoIP() → Future<String>
Get device push token VoIP.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
showMissCallNotification(CallEvent data) → Future<void>
Show Miss Call Notification.
override
startCall(CallEvent data) → Future<void>
Start an Outgoing call.
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited